==> beast-privilege-api-3.0.16-sources.jar: com/thebeastshop/privilege/vo/OcrTranslateResultVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class OcrTranslateResultVO implements Serializable {
    private Integer id;
    private Integer prodId;
    private String prodCode;
    private String lang;
    private String sourceName;
    private String name;
    private String nameCn;
    private String attr1;
    private String attr1V1;
    private String attr2;
    private String attr2V2;
    private String attr3;
    private String attr3V3;
    private Date createTime;
    private Integer totalMilliseconds;
    private Integer requestMilliseconds;

    private Integer successCount;

    private Integer faildCount;

    private Integer charLength;
    private Integer status;
    private String statusText;
    private String dync;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getLang() {
        return lang;
    }

    public void setLang(String lang) {
        this.lang = lang;
    }

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameCn() {
        return nameCn;
    }

    public void setNameCn(String nameCn) {
        this.nameCn = nameCn;
    }

    public String getAttr1() {
        return attr1;
    }

    public void setAttr1(String attr1) {
        this.attr1 = attr1;
    }

    public String getAttr1V1() {
        return attr1V1;
    }

    public void setAttr1V1(String attr1V1) {
        this.attr1V1 = attr1V1;
    }

    public String getAttr2() {
        return attr2;
    }

    public void setAttr2(String attr2) {
        this.attr2 = attr2;
    }

    public String getAttr2V2() {
        return attr2V2;
    }

    public void setAttr2V2(String attr2V2) {
        this.attr2V2 = attr2V2;
    }

    public String getAttr3() {
        return attr3;
    }

    public void setAttr3(String attr3) {
        this.attr3 = attr3;
    }

    public String getAttr3V3() {
        return attr3V3;
    }

    public void setAttr3V3(String attr3V3) {
        this.attr3V3 = attr3V3;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getTotalMilliseconds() {
        return totalMilliseconds;
    }

    public void setTotalMilliseconds(Integer totalMilliseconds) {
        this.totalMilliseconds = totalMilliseconds;
    }

    public Integer getRequestMilliseconds() {
        return requestMilliseconds;
    }

    public void setRequestMilliseconds(Integer requestMilliseconds) {
        this.requestMilliseconds = requestMilliseconds;
    }

    public Integer getSuccessCount() {
        return successCount;
    }

    public void setSuccessCount(Integer successCount) {
        this.successCount = successCount;
    }

    public Integer getFaildCount() {
        return faildCount;
    }

    public void setFaildCount(Integer faildCount) {
        this.faildCount = faildCount;
    }

    public Integer getCharLength() {
        return charLength;
    }

    public void setCharLength(Integer charLength) {
        this.charLength = charLength;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getStatusText() {
        return statusText;
    }

    public void setStatusText(String statusText) {
        this.statusText = statusText;
    }

    public String getDync() {
        return dync;
    }

    public void setDync(String dync) {
        this.dync = dync;
    }
}

==> beast-privilege-api-3.0.17-sources.jar: com/thebeastshop/privilege/vo/OcrTranslateResultVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class OcrTranslateResultVO implements Serializable {
    private Integer id;
    private Integer prodId;
    private String prodCode;
    private String lang;
    private String sourceName;
    private String name;
    private String nameCn;

    private String picList;

    private String attr1;
    private String attr1V1;
    private String attr2;
    private String attr2V2;
    private String attr3;
    private String attr3V3;
    private Date createTime;
    private Integer totalMilliseconds;
    private Integer requestMilliseconds;

    private Integer successCount;

    private Integer faildCount;

    private Integer charLength;
    private Integer status;
    private String statusText;
    private String dync;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getLang() {
        return lang;
    }

    public void setLang(String lang) {
        this.lang = lang;
    }

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameCn() {
        return nameCn;
    }

    public void setNameCn(String nameCn) {
        this.nameCn = nameCn;
    }

    public String getPicList() {
        return picList;
    }

    public void setPicList(String picList) {
        this.picList = picList;
    }

    public String getAttr1() {
        return attr1;
    }

    public void setAttr1(String attr1) {
        this.attr1 = attr1;
    }

    public String getAttr1V1() {
        return attr1V1;
    }

    public void setAttr1V1(String attr1V1) {
        this.attr1V1 = attr1V1;
    }

    public String getAttr2() {
        return attr2;
    }

    public void setAttr2(String attr2) {
        this.attr2 = attr2;
    }

    public String getAttr2V2() {
        return attr2V2;
    }

    public void setAttr2V2(String attr2V2) {
        this.attr2V2 = attr2V2;
    }

    public String getAttr3() {
        return attr3;
    }

    public void setAttr3(String attr3) {
        this.attr3 = attr3;
    }

    public String getAttr3V3() {
        return attr3V3;
    }

    public void setAttr3V3(String attr3V3) {
        this.attr3V3 = attr3V3;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getTotalMilliseconds() {
        return totalMilliseconds;
    }

    public void setTotalMilliseconds(Integer totalMilliseconds) {
        this.totalMilliseconds = totalMilliseconds;
    }

    public Integer getRequestMilliseconds() {
        return requestMilliseconds;
    }

    public void setRequestMilliseconds(Integer requestMilliseconds) {
        this.requestMilliseconds = requestMilliseconds;
    }

    public Integer getSuccessCount() {
        return successCount;
    }

    public void setSuccessCount(Integer successCount) {
        this.successCount = successCount;
    }

    public Integer getFaildCount() {
        return faildCount;
    }

    public void setFaildCount(Integer faildCount) {
        this.faildCount = faildCount;
    }

    public Integer getCharLength() {
        return charLength;
    }

    public void setCharLength(Integer charLength) {
        this.charLength = charLength;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getStatusText() {
        return statusText;
    }

    public void setStatusText(String statusText) {
        this.statusText = statusText;
    }

    public String getDync() {
        return dync;
    }

    public void setDync(String dync) {
        this.dync = dync;
    }
}
